Documentation
¶
Index ¶
- func CapitaliseFirstLetter(s string) string
- func CombineUnique(originals []string, candidates []string) []string
- func Contains(entries []string, searchTerm string) bool
- func ContainsPrefix(entries []string, searchTerm string) bool
- func GetFirstNonEmpty(candidates ...string) string
- func GetMatchingSuffix(entry string, suffixes []string) string
- func Sha1hash(input []byte) string
- func Sha1hashString(input string) string
- func ToBool(input string) bool
- func ToBoolWithDefault(input string, defaultValue bool) bool
- func Unique(candidates []string) []string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CapitaliseFirstLetter ¶
func CombineUnique ¶
CombineUnique returns the unique union of originals and candidates
func ContainsPrefix ¶
func GetFirstNonEmpty ¶
func GetMatchingSuffix ¶
GetMatchingSuffix checks if entry has at least one of the given suffixes. If a suffix matches, it is returned, otherwise an empty string is returned.
func Sha1hash ¶
Sha1hash returns a SHA1 checksum of the given input string. This *must not* be used for cryptographic purposes, as SHA1 is not secure.
func Sha1hashString ¶
Sha1hashString returns a SHA1 checksum of the given input string. This *must not* be used for cryptographic purposes, as SHA1 is not secure.
func ToBoolWithDefault ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.